package com.cmvr.device.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.cmvr.device.domain.DeDeviceRegistration;
import org.apache.ibatis.annotations.Mapper;

/**
 * 设备注册Mapper接口
 * 
 * @author cmvr-iot
 * @date 2025-05-08
 */
@Mapper
public interface DeDeviceRegistrationMapper extends BaseMapper<DeDeviceRegistration>
{
    /**
     * 查询设备注册
     * 
     * @param id 设备注册主键
     * @return 设备注册
     */
    public DeDeviceRegistration selectDeDeviceRegistrationById(String id);


    /**
     * 查询设备表中所有的设备编号
     * @return 设备编号集合
     */
    public List<String> selectAllDeviceCode();


    public String selectDeviceModelById(String id);


    /**
     * 查询设备注册列表
     * 
     * @param deDeviceRegistration 设备注册
     * @return 设备注册集合
     */
    public List<DeDeviceRegistration> selectDeDeviceRegistrationList(DeDeviceRegistration deDeviceRegistration);

    /**
     * 新增设备注册
     * 
     * @param deDeviceRegistration 设备注册
     * @return 结果
     */
    public int insertDeDeviceRegistration(DeDeviceRegistration deDeviceRegistration);

    /**
     * 修改设备注册
     * 
     * @param deDeviceRegistration 设备注册
     * @return 结果
     */
    public int updateDeDeviceRegistration(DeDeviceRegistration deDeviceRegistration);

    /**
     * 删除设备注册
     * 
     * @param id 设备注册主键
     * @return 结果
     */
    public int deleteDeDeviceRegistrationById(String id);

    /**
     * 批量删除设备注册
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDeDeviceRegistrationByIds(String[] ids);
}
